Package: netresponse
Type: Package
Title: Functional Network Analysis
Version: 1.73.0
Date: 2023-04-03
Author: Leo Lahti, Olli-Pekka Huovilainen, Antonio Gusmao and Juuso
        Parkkinen
Maintainer: Leo Lahti <leo.lahti@iki.fi>
Description: Algorithms for functional network analysis. Includes an
        implementation of a variational Dirichlet process Gaussian
        mixture model for nonparametric mixture modeling.
License: GPL (>=2)
Depends: R (>= 2.15.1), BiocStyle, Rgraphviz, rmarkdown, methods,
        minet, mclust, reshape2
Imports: ggplot2, graph, igraph, parallel, plyr, qvalue, RColorBrewer
Suggests: knitr
URL: https://github.com/antagomir/netresponse
BugReports: https://github.com/antagomir/netresponse/issues
biocViews: CellBiology, Clustering, GeneExpression, Genetics, Network,
        GraphAndNetwork, DifferentialExpression, Microarray,
        NetworkInference, Transcription
VignetteBuilder: knitr
RoxygenNote: 7.2.3
Config/pak/sysreqs: cmake libglpk-dev make libicu-dev libuv1-dev
        libxml2-dev zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 12:34:52 UTC
RemoteUrl: https://github.com/bioc/netresponse
RemoteRef: HEAD
RemoteSha: 8072ad494852aeac63b603fae099ccdd7fea300d
NeedsCompilation: yes
Packaged: 2026-05-04 09:13:21 UTC; root
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-04 09:25:18 UTC; unix
