# Generated by roxygen2: do not edit by hand

export(centerData)
export(continuous.responses)
export(detect.responses)
export(enrichment.list.factor.minimal)
export(factor.responses)
export(factor.responses.minimal)
export(find.similar.features)
export(generate.toydata)
export(get.model.parameters)
export(independent.models)
export(list.responses.continuous.multi)
export(list.responses.continuous.single)
export(listify.groupings)
export(mixture.model)
export(model.stats)
export(order.responses)
export(pick.model.parameters)
export(plot_matrix)
export(plot_response)
export(plot_responses)
export(plot_subnet)
export(response2sample)
export(sample2response)
export(set.breaks)
export(vdp.mixt)
exportMethods(get.subnets)
import(RColorBrewer)
import(Rgraphviz)
import(graph)
import(mclust)
import(methods)
import(parallel)
importFrom(BiocStyle,pkg_ver)
importFrom(ggplot2,aes)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,qplot)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_set)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,gray)
importFrom(grDevices,palette)
importFrom(grDevices,rainbow)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,hist)
importFrom(graphics,image)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(igraph,graph.data.frame)
importFrom(igraph,graph.edgelist)
importFrom(igraph,igraph.from.graphNEL)
importFrom(igraph,igraph.to.graphNEL)
importFrom(igraph,subgraph)
importFrom(minet,build.mim)
importFrom(plyr,ddply)
importFrom(qvalue,qvalue)
importFrom(reshape2,melt)
importFrom(rmarkdown,render)
importFrom(stats,cor)
importFrom(stats,dnorm)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,phyper)
importFrom(stats,prcomp)
importFrom(stats,princomp)
importFrom(stats,qchisq)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(utils,read.csv)
useDynLib(netresponse)
