[![Build Status](https://api.travis-ci.org/antagomir/netresponse.png)](https://travis-ci.org/antagomir/netresponse)
<!--[![Stories in Ready](https://badge.waffle.io/antagomir/netresponse.png?label=Ready)](http://waffle.io/antagomir/netresponse)-->
<!--[![DOI](https://zenodo.org/badge/4203/rOpenGov/sorvi.png)](https://github.com/rOpenGov/sorvi)-->

netresponse 
===========

Tools for functional network analysis (follow links for references):

 * [netresponse](http://bioinformatics.oxfordjournals.org/content/26/21/2713)
   discover context-specific activation patterns in interaction
   networks

 * [Interaction Component Model
   ICMg](http://www.biomedcentral.com/1752-0509/4/4) to discover
   network modules. Can be supervised by functional information of the
   network.

For installation and usage, check the [tutorial page](vignettes/NetResponse.md).

<!--_Bioinformatics_ 2011. {[Abstract](http://bioinformatics.oxfordjournals.org/content/26/21/2713) | [Preprint pdf](http://www.roihu.info/publications/preprints/Lahti10bioinf-preprint.pdf)}-->


### Support

You are welcome to:
  
  * [submit suggestions and bug reports](https://github.com/antagomir/netresponse/issues)
  * [send a pull request](https://github.com/antagomir/netresponse/)
  * ping antagomir at IRCnet or FreeNode


### Authors

Maintainer: [Leo Lahti](http://www.iki.fi/Leo.Lahti)

Contributors: Olli-Pekka Huovilainen, Antonio Gusmao, Juuso Parkkinen  

Acknowledgements: This program is partially based on the
[AIVGA](http://www.cis.hut.fi/projects/ivga/) Agglomerative
Independent Variable Group Analysis source code (v. 1.0) Copyright (C)
2001-2007 Esa Alhoniemi, Antti Honkela, Krista Lagus, Jeremias Seppa,
Harri Valpola, and Paul Wagner.

[Matlab
implementation](http://www.cis.hut.fi/projects/mi/software/NetResponse)
is also available but not supported.

