setClass("NetResponseModel", representation(moves = "matrix",
    last.grouping = "list", 
    subnets = "list", params = "list", datamatrix = "matrix",
    network = "graphNEL", 
    models = "list"))
