% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pkg-package.R
\docType{class}
\name{NetResponseModel-class}
\alias{NetResponseModel-class}
\alias{[[,NetResponseModel-method}
\alias{show,NetResponseModel-method}
\title{Class 'NetResponseModel'}
\description{
A NetResponse model.
}
\section{Objects from the Class}{
 Returned by \code{\link{detect.responses}}
function.
}

\examples{
showClass('NetResponseModel')
}
\author{
Leo Lahti \email{leo.lahti@iki.fi}
}
\keyword{classes}
