% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/order.responses.R
\name{list.significant.responses}
\alias{list.significant.responses}
\title{Listing significant responses}
\usage{
list.significant.responses(model, sample, qth = 1, method = "hypergeometric")
}
\arguments{
\item{model}{NetResponseModel object.}

\item{sample}{User-specified samples group for which the enrichments are
calculated. For instance, an annotation category.}

\item{qth}{q-value threshold for enrichments}

\item{method}{Enrichment method.}
}
\value{
Statistics of the significantly associated responses.
}
\description{
List responses with significant associations to a given sample group.
}
\examples{
# 
}
\references{
See citation('netresponse')
}
\seealso{
response.enrichment
}
\author{
Leo Lahti \email{leo.lahti@iki.fi}
}
\keyword{utilities}
