% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pick.model.parameters.R
\name{pick.model.parameters}
\alias{pick.model.parameters}
\title{pick.model.parameters}
\usage{
pick.model.parameters(m, nodes)
}
\arguments{
\item{m}{vdp.mixt output}

\item{nodes}{node names for naming purposes}
}
\value{
Model parameters
}
\description{
Pick model parameters
}
\examples{
pick.model.parameters(m = NULL, nodes = NULL) 
}
\references{
See citation('netresponse')
}
\author{
Leo Lahti \email{leo.lahti@iki.fi}
}
\keyword{internal}
