% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot-methods.R
\name{plot_expression}
\alias{plot_expression}
\title{plot_expression}
\usage{
plot_expression(x, maintext, ...)
}
\arguments{
\item{x}{samples x features matrix}

\item{maintext}{main title}

\item{...}{optional arguments}
}
\value{
Used for its side effects.
}
\description{
Plot expression matrix in color scale. For one-channel data;
plot expression
of each gene relative to its mean expression level over all samples. Blue
indicates decreased expression and red indicates increased expression.
Brightness of the color indicates magnitude of the change. Black denotes no
change.
}
\examples{
#plot_expression(x)
}
\references{
See citation('netresponse').
}
\seealso{
\code{\link{plot_scale}}
}
\author{
Leo Lahti \email{leo.lahti@iki.fi}
}
\keyword{utilities}
